<?

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */

////////////////////////////////////////////////////////////
// "Shared" variables
////////////////////////////////////////////////////////////

// With regard to the following variables:
// each locale must include them from all the other locales...
// this makes the locales not totally independent of each other :(
$Choose_italian_language = "Mostra sito in lingua Italiana";
$Choose_english_language = "Go to the English version of the site";
//

$Home_Page = "Pagina principale";
$Administration = "Amministrazione";
$Login = "Login";
$Logout = "Logout";
$Username = "Username";
$Password = "Password";
$Password_Confirm = "Password (conferma)";
$Change_Password = "Modifica Password";
$Edit = "Modifica";
$Delete = "Elimina";
$Remove = "Rimuovi";
$Total = "Totale";
$Delivery = "Spedizione";
$Cash_On_Delivery = "Contrassegno";
$Credit_Card = "Carta di Credito";
$Category = "Categoria";
$Categories = "Categorie";
$Categories_Browsing = "Navigazione delle Categorie";
$The_category = "La categoria";
$Brand = "Marca";
$Brands = "Marche";
$The_brand = "La marca";
$The_IVA_Percentual = "La percentuale di IVA";
$Product = "Prodotto";
$Products = "Prodotti";
$The_product = "Il prodotto";
$Add_Product = "Aggiungi prodotto";
$Delete_Product = "Elimina prodotto";
$Edit_Product = "Modifica prodotto";
$Items = "pezzi";
$Add_Subcategory = "Aggiungi sottocategoria";
$Add_Brand = "Aggiungi marca";
$Add_IVA = "Aggiungi IVA";
$back = "indietro";
$BACK = "INDIETRO";
$Address = "Via/Piazza";
$Number = "Numero";
$City = "Comune";
$State = "Citt&agrave;";
$Zip_Code = "CAP";
$Phone = "Telefono";
$Fax = "Fax";
$MobilePhone = "Cellulare";
$Order_Details = "Dettagli dell'ordine";
$Price = "Prezzo";
$Weight = "Peso";
$Total_weight = "Peso totale";
$Qty = "Q.t&agrave;";
$Sub_Total = "Sub Totale";
$Grand_Total = "Totale complessivo";
$Payment_Methods = "Metodi di pagamento";
$Add_to_cart = "+ Aggiungi al carrello";
$Add_to_Shopping_Cart = "+ Aggiungi al carrello della spesa";
$Image = "Immagine";
$Notes = "Annotazioni";
$Our_Notes = "Nostre Annotazioni";
$Change_Settings = "Modifica Impostazioni";
$First_Name = "Nome";
$Last_Name = "Cognome";
$Fiscal_Code = "Codice Fiscale";
$E_mail = "E-mail";
$Import_Button_Label = "Importa";
$Reset_Form = "Svuota form";

////////////////////////////////////////////////////////////
// Top level scripts
////////////////////////////////////////////////////////////

$login_failed = "Login fallito, riprova";

////////////////////////////////////////////////////////////
// Top level templates
////////////////////////////////////////////////////////////

$footer_message = $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"";
$Errors = "Errori";
$Contact_us = "Contattaci !";
$Signup_Italy = "Iscrizione (Italia)";
$Signup_non_Italy = "Iscrizione (Estero)";
$Enterprises_Signup = "Iscrizione Aziende";
$Shopping = "Acquisto";
$Purchase_Now = "Acquista ora";
$Search_the_Catalog = "Cerca nel catalogo";
$At_least_a_word = "Almeno una parola";
$All_the_words = "Tutte le parole";
$Case_Sensitive = "Distingui Maiuscole";
$Search_excl = "Cerca !";
$Insufficient_Privileges = "Diritti insufficienti";
$No_Orders = "Nessun Ordine";
$No_Such_Order = "Non c'&egrave; nessun ordine con l'identificativo richiesto";
$PgMarket_Login = $CFG->myname . " Login";
$PgMarket_Login_Page = $CFG->myname . ": pagina di login";
$sign_up_for_an_account_now = "Se non sei gi&agrave; iscritto a questo negozio elettronico, iscriviti ora:";
$dont_login_back_to_home_page = "Se non desideri ancora effettuare la procedura di login, <a href=\"".$CFG->firstpage."\">clicca qui</a> per tornare alla pagina principale (home page).";
$Special_Products = "Prodotti speciali";

////////////////////////////////////////////////////////////
// admin scripts
////////////////////////////////////////////////////////////

$Add_User = "Aggiungi utente";
$Categories_Management = "Amministrazione delle categorie";
$C_Import_Categories = "Importa categorie";
$Brands_Management = "Amministrazione delle marche";
$C_Import_Brands = "Importa marche";
$C_Import_IVA = "Importa percentuali IVA";
$IVA_Management = "Amministrazione dei valori di IVA";
$Orders_Log_ca = "Diario degli ordini - Contrassegno";
$Orders_Log_cc = "Diario degli ordini - Carta di Credito";
$Products_Management = "Amministrazione dei prodotti";
$C_Import_Products = "Importa prodotti";
$Save_Changes = "Salva modifiche";
$Users_Admin = "Amministrazione degli utenti";
$U_Import_Users = "Importa utenti";
$_Import_File = "File da Importare:";
$Import_Images_Button_Label = "Importa Immagini";
$C_Import_Images = "Importa immagini";
$End_Import = "Import Terminato.";

////////////////////////////////////////////////////////////
// admin templates
////////////////////////////////////////////////////////////

$Parent = "Padre";
$Name = "Nome";
$Description = "Descrizione";
$Extended_Description = "Descrizione estesa";
$Discount = "Sconto";
$Starting_from = "a partire da";
$C_Add_Category = "[+C] Aggiungi categoria";
$C_Add_Brand = "[+C] Aggiungi marca";
$C_Add_IVA = "[+C] Aggiungi percentuale IVA";
$C_Add_Product = "[+P] Aggiungi prodotto";
$Action = "Azione";
$User = "Utente";
$The_user = "L'utente";
$data_have_been_updated = "i dati sono stati modificati";
$has_been_added_female_singular = "&egrave; stata creata";
$has_been_added_male_singular = "&egrave; stato creato";
$has_been_updated_female_singular = "&egrave; stata modificata";
$has_been_updated_male_singular = "&egrave; stato modificato";
$has_been_deleted_female_singular = "&egrave; stata eliminata";
$has_been_deleted_male_singular = "&egrave; stato eliminato";
$All_the_products_and_sub_categories_belonging_to = "Tutti i prodotti e le sottocategorie appartenenti a";
$have_been_reassigned_to_male_plural = "sono stati riassegnati a";
$actually_its_name_is_female_singular = "attualmente si chiama";
$actually_its_value_is_female_singular = "attualmente vale";
$Add_a_subcategory_under = "Aggiungi una sottocategoria di";
$Add_a_product_under = "Aggiungi un prodotto a";
$Edit_this_category = "Modifica questa categoria";
$Edit_this_brand = "Modifica questa marca";
$Edit_this_IVA = "Modifica questa percentuale di IVA";
$admin_footer_message = $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"";
$Brand_reset_for_products = "La marca &egrave; stata azzerata per i prodotti di tale marca";
$IVA_reset_for_products = "La percentuale di IVA &egrave; stata azzerata per i prodotti con tale IVA";
$Users = "Utenti";
$Edit_this_order = "Modifica questo ordine";
$Delete_this_order = "Cancella questo ordine";
$Order = "Ordine";
$Orders = "Ordini";
$The_order = "L'ordine";
$Sent = "Spedito";
$Paid = "Pagato";
$Ordered = "Ordinato";
$Ordered_By = "Ordinato da";
$Amount = "Ammontare";
$Customer_Info = "Informazioni sul cliente";
$Enterprise_Id_N = "Partita IVA";
$ID = "ID";
$Current_Price = "Prezzo attuale";
$Purchase_Price = "Prezzo d'acquisto";
$Order_Status = "Stato dell'ordine";
$ID_and_Status = "ID - Stato";
$Status = "Stato";
$Cust_Info = "Info cliente";
$Details = "Dettagli";
$Special = "Speciale";
$Normal = "Normale";
$Edit_this_product = "Modifica questo prodotto";
$View_product_details = "Mostra dettagli del prodotto";
$Privilege = "Privilegio";
$Enterprise_Name = "Ragione Sociale";
$Enterprise_identification_number = "Partita IVA";
$Auth_data_handling_az = "Aut. tratt. dati az.";
$Auth_data_handling_pf = "Aut. tratt. dati pers.";
$Accept_advert_matherial = "Disp. a ricevere mat. p.";
$Registration_Date = "Data iscr.";
$Authorization_for_data_handling_az = "Autorizzazione al trattamento dei dati aziendali";
$Authorization_for_data_handling_pf = "Autorizzazione al trattamento dei dati personali";
$Acceptance_of_advertising_matherial = "Disponibilit&agrave; a ricevere materiale pubblicitario";
$U_Add_User = "[+U] Aggiungi Persona Fisica";
$U_Add_Enterprise_User = "[+U] Aggiungi Azienda";
$Data_handl = "Tratt. dati";
$Advert = "Acc. pubbl.";
$Reset_password_for = "Reinizializza la password di";
$Change_password_for = "Modifica la password di";
$Edit_this_user = "Modifica questo utente";
$Email_this_user = "Scrivi a questo utente";

////////////////////////////////////////////////////////////
// shopping scripts
////////////////////////////////////////////////////////////

$Cart = "Carrello";
$Shopping_Cart = "Carrello della spesa";
$Checkout = "Cassa";
$Order_Completed_Successfully = "Ordine completato con successo";
$Product_Details = "Dettagli del prodotto: ";
$Product_Not_Found = "Prodotto non trovato";
$Shopping_Catalog = "Catalogo dei prodotti in vendita";
$Unable_To_Complete_The_Order = "Impossibile completare l'ordine";

////////////////////////////////////////////////////////////
// shopping templates
////////////////////////////////////////////////////////////

$None_Female_Singular = "Nessuna";
$None_Male_Singular = "Nessuno";
$Product_not_found = "Prodotto non trovato";
$Sorry_product_not_found = "Spiacente, il prodotto cercato non &egrave; stato trovato.  Sei pregato di cercare <a href=\"".$CFG->wwwroot."/shopping/\">nel nostro catalogo</a> per trovare quello che cerchi.";
$Purchase_Confirmation = "Conferma dell'acquisto";
$Your_shopping_cart_is_empty = "Il tuo carrello &egrave; vuoto, <a href=\"".$CFG->wwwroot."/shopping/\">consulta il catalogo dei prodotti</a>.";
$Billing_Details = "Dettagli dell'acquisto";
$Date = "Data";
$Bill_to = "Venduto a";
$Contact = "Recapito";
$Comments_and_Special_Instructions = "Commenti / Istruzioni speciali";
$Step_1_Enter_Billing_Information = "Passo 1. Inserisci le informazioni per l'acquisto";
$Customer = "Cliente";
$Phone_Contact = "Recapito telefonico";
$Step_2_Comments_and_Special_Instructions = "Passo 2. Commenti / Istruzioni speciali";
$Next_Step = "Passo Successivo";
$Search_Results = "Risultati della ricerca";
$on = "su";
$pages = "pagine";
$Your_Shopping_Cart_Contains = "Il tuo carrello contiene";
$Continue_Shopping = "Altri acquisti";
$Recalculate_Cart = "Ricalcola Carrello";
$Empty_the_Cart = "Svuota il carrello";

////////////////////////////////////////////////////////////
// users scripts
////////////////////////////////////////////////////////////

$Password_Change_Successful = "Modifica della password effettuata con successo";
$Settings_Change_Successful = "Impostazioni modificate con successo";
$Signup = "Iscrizione";
$Signup_Successful = "Iscrizione effettuata con successo";
$Contact_Us = "Contattaci via E-mail";
$Contact_Successful = "E-mail inviata con successo";

////////////////////////////////////////////////////////////
// users templates
////////////////////////////////////////////////////////////

$Min_Username_Length = "(min. ". $SESSION["username_length_min"] . " caratteri)";
$Old_Password = "Vecchia Password";
$New_Password = "Nuova Password";
$Confirm_Password = "Conferma Password";
$I_agree_with_the_usage_of_the_presently_given_data = "Autorizzo il trattamento dei dati qui forniti";
$I_accept_to_receive_advertising_matherial = "Accetto di ricevere materiale pubblicitario";
$I_agree_with_the_usage_of_my_personal_data = "Autorizzo il trattamento dei miei dati personali";
$appoggio = return_star();
$Please_fill_out_this_contact_form = "Sei pregato di riempire il seguente modulo; tieni presente che &egrave; necessario riempire tutti i campi contrassegnati con un asterisco (" . $appoggio . ").";
$First_and_Last_Name = "Nome e Cognome<br>(o Ragione Sociale)";
$Message = "Messaggio";
$Send = "Spedisci";

////////////////////////////////////////////////////////////
// ERROR MESSAGES
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// signup, contact us
////////////////////////////////////////////////////////////

$the_username = "La Username";
$already_exists = " &egrave; gi&agrave; in uso";

$empty_username = "Non &egrave; stata specificata la Username";
$username_too_long = "Username troppo lunga: ".$SESSION["username_length"]." caratteri max";
$username_too_short = "Username troppo corta: ".$SESSION["username_length_min"]." caratteri min";
$not_valid_username = "Username non valida: usare solo caratteri alfanumerici";

$passwords_do_not_match = "Le password fornite non coincidono";
$empty_password = "Non &egrave; stata specificata la Password";
$please_enable_javascript =
"<b>
Per motivi di sicurezza, per poter acquistare nel nostro negozio virtuale
&egrave; necessario usare JavaScript.
<p>
Il linguaggio JavaScript, oltre a offrire funzionalit&agrave;
molto utili nella realizzazione di software per il Web,
permette di criptare le password e, quindi, di offrire molta sicurezza
in pi&ugrave; a chi fa uso di questo negozio virtuale.
<p>
Perci&ograve; per acquistare nel nostro negozio virtuale &egrave; necessario
un navigatore che supporti JavaScript, come ad esempio Netscape o Explorer.
Se si sta usando un navigatore che supporta JavaScript ma tale supporto
&egrave; stato disabilitato, si prega di modificare le impostazioni
in modo da abilitare JavaScript.
<p>
Nota: le impostazioni di default di Netscape ed Explorer
prevedono l'uso di JavaScript.
</b><br><br>";

$empty_firstname = "Non &egrave; stato specificato il Nome";
$firstname_too_long = "Nome troppo lungo: ".$SESSION["firstname_length"]." caratteri max";

$empty_ragionesociale = "Non &egrave; stata specificata la Ragione Sociale";
$ragionesociale_too_long = "Ragione Sociale troppo lunga: ".$SESSION["firstname_length"]." caratteri max";

$empty_lastname = "Non &egrave; stato specificato il Cognome";
$lastname_too_long = "Cognome troppo lungo: ".$SESSION["lastname_length"]." caratteri max";

$empty_name = "Non &egrave; stato specificato il Nome";
$name_too_long = "Nome troppo lungo: ".$SESSION["name_length"]." caratteri max";

$empty_fiscalcode = "Non &egrave; stato specificato il Codice Fiscale";
$bad_fiscalcode_length = "Il Codice Fiscale deve contenere ".$SESSION["fiscalcode_length"]." caratteri alfanumerici";
$not_valid_fiscalcode = "Codice Fiscale non valido";

$empty_partitaiva = "Non &egrave; stata specificata la Partita IVA";
$bad_partitaiva_length = "La Partita IVA deve contenere ".$SESSION["partitaiva_length"]." cifre";
$not_valid_partitaiva = "Partita IVA non valida";

$empty_address = "Non &egrave; stato specificato l'indirizzo";
$address_too_long = "Via/Piazza troppo lunga: ".$SESSION["address_length"]." caratteri max";

$number_too_long = "Numero troppo lungo: ".$SESSION["number_length"]." caratteri max";

$empty_city = "Non &egrave; stato specificato il comune";
$city_too_long = "Comune troppo lungo: ".$SESSION["city_length"]." caratteri max";

$empty_state = "Non &egrave; stata specificata la citt&agrave;";
$state_too_long = "Citt&agrave; troppo lunga: ".$SESSION["state_length"]." caratteri max";

$empty_zip_code = "Riempire il campo del CAP";
$zip_code_is_zero = "Il CAP deve essere maggiore di zero";
$zip_code_notint = "Il campo del CAP deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$zip_code_length_is_wrong = "Il CAP deve contenere esattamente " . $SESSION["zip_code_length"] . " cifre";

$empty_phone = "Non &egrave; stato specificato il numero di telefono";
$phone_too_long = "Numero di telefono troppo lungo: ".$SESSION["phone_length"]." caratteri max";
$phone_too_short = "Numero di telefono troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
$not_valid_phone = "Numero di telefono non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$fax_too_long = "Numero di fax troppo lungo: ".$SESSION["fax_length"]." caratteri max";
$fax_too_short = "Numero di fax troppo corto: ".$SESSION["fax_length_min"]." caratteri min";
$not_valid_fax = "Numero di fax non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$mobilephone_too_long = "Numero di cellulare troppo lungo: ".$SESSION["mobilephone_length"]." caratteri max";
$mobilephone_too_short = "Numero di cellulare troppo corto: ".$SESSION["mobilephone_length_min"]." caratteri min";
$not_valid_mobilephone = "Numero di cellulare non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$empty_email = "Non &egrave; stato specificato l'indirizzo e-mail";
$email_too_long = "Indirizzo e-mail troppo lungo: ".$SESSION["email_length"]." caratteri max";
$not_valid_email = "Indirizzo E-mail non valido";
//$the_email_address = "L'indirizzo E-mail";
//$email_not_on_file = "L'indirizzo E-mail specificato non ci risulta noto";

$notes_too_long = "Annotazioni troppo lunghe: ".$SESSION["notes_length"]." caratteri max";
$ournotes_too_long = "Annotazioni troppo lunghe nel campo \"" . $Our_Notes . "\": ".$SESSION["ournotes_length"]." caratteri max";
$empty_message = "Non &egrave; stato scritto nessun Messaggio";
$message_too_long = "Messaggio troppo lungo: ".$SESSION["message_length"]." caratteri max";

////////////////////////////////////////////////////////////
// purchase now
////////////////////////////////////////////////////////////

$empty_customer = "Non &egrave; stato specificato il Cliente";
$appoggio = $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1;
$customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri max";
$empty_contact = "Non &egrave; stato specificato un recapito telefonico";
$contact_too_long = "Recapito telefonico troppo lungo: ".$SESSION["phone_length"]." caratteri max";
$contact_too_short = "Recapito telefonico troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
$not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
$comments_too_long = "Commenti troppo lunghi: ".$SESSION["comments_length"]." caratteri max";

////////////////////////////////////////////////////////////
// change password
////////////////////////////////////////////////////////////

$no_old_password = "Non &egrave; stata specificata la vecchia password";
$old_password_not_valid = "La vecchia password &egrave; sbagliata";
$no_new_password = "Non &egrave; stata specificata la nuova password";
$no_new_password2 = "Non &egrave; stata confermata la nuova password";
$new_passwords_dont_match = "Le nuove password non coincidono";

////////////////////////////////////////////////////////////
// add and update category
////////////////////////////////////////////////////////////

$empty_category_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$category_name_too_long = "Il nome della categoria &egrave; troppo lungo: ".$SESSION["category_name_length"]." caratteri max";
$category_description_too_long = "La descrizione della categoria &egrave; troppo lunga: ".$SESSION["category_description_length"]." caratteri max";

$priv_too_long = "Privilegio troppo lungo: ".$SESSION["priv_length"]." caratteri max";
$not_valid_priv = "Privilegio non valido: usare solo caratteri alfanumerici";

$Err_ImpCat = ": la Categoria Padre non esiste - '";

////////////////////////////////////////////////////////////
// add and update brand
////////////////////////////////////////////////////////////

$empty_brand_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$brand_name_too_long = "Il nome della marca &egrave; troppo lungo: ".$SESSION["brand_name_length"]." caratteri max";
$brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: ".$SESSION["brand_description_length"]." caratteri max";

$Err_ImpBrand = ": La Marca non esiste - '";
$Err_ImpIVA = ": L'IVA non esiste - '";

////////////////////////////////////////////////////////////
// add and update product
////////////////////////////////////////////////////////////

$product_id_is_empty = "Il campo ID &egrave; stato lasciato vuoto, si prega di riempirlo";
$product_id_wspace = "L'ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contiene almeno uno spazio. Si prega di non usare spazi negli ID dei prodotti.";
$product_id_wampersand = "L'ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contiene il carattere \"&amp;\". Si prega di non usarlo negli ID dei prodotti.";
$product_id_wquestionm = "L'ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contiene il carattere \"?\". Si prega di non usarlo negli ID dei prodotti.";
$product_id_too_long = "L'ID del prodotto &egrave; troppo lungo: ".$SESSION["product_id_length"]." caratteri max";
$the_product_id = "L'ID ";

$empty_product_name = "Riempire il campo del Nome del prodotto";
$product_name_too_long = "Il nome del prodotto &egrave; troppo lungo: ".$SESSION["product_name_length"]." caratteri max";

$empty_price = "Riempire il campo del prezzo";
$price_is_zero = "Il Prezzo deve essere maggiore di zero";
$price_notint = "Il campo del Prezzo deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$price_notfloat = "Il campo del Prezzo deve contenere un numero decimale, quindi solo cifre e al pi&ugrave; un punto decimale, nessun altro carattere";

$not_valid_iva = "Valore dell'IVA non valido";
$iva_not_between_0_and_100 = "L'IVA non &egrave; compresa tra 0 e 100";

$discount_not_completely_defined = "Se si vuole fare sconti sul prodotto, bisogna riempire sia il campo \"" . $Discount . "\" che il campo \"" . $Starting_from . "\"; se non si vuole fare sconti sul prodotto, lasciare vuoti entrambi i campi";
$not_valid_discount = "Sconto non valido";
$discount_not_between_0_and_100 = "Lo Sconto non &egrave; compreso tra 0 e 100";
$discqty_notint = "Il campo \"" . $Starting_from . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$discqty_is_negative = "Il campo \"" . $Starting_from . "\" non pu&ograve; essere un numero negativo";
$discqty_is_too_large = "Il campo \"" . $Starting_from . "\" &egrave; troppo grande: " . $SESSION["discqtymax"] . " max";

$empty_weight = "Riempire il campo del Peso";
$not_valid_weight = "Peso non valido";
$weight_is_zero = "Il Peso deve essere maggiore di zero";
$weight_over_max = "Peso eccessivo: " . $SESSION["weightmax"] . " " . $weightunity . " max";

$on_special_empty = "Riempire il campo \"" . $Special . "\"";
$on_special_notint = "Il campo \"" . $Special . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";

$product_description_too_long = "La descrizione del prodotto &egrave; troppo lunga: ".$SESSION["product_description_length"]." caratteri max";
$product_extended_description_too_long = "La descrizione estesa del prodotto &egrave; troppo lunga: ".$SESSION["product_extended_description_length"]." caratteri max";

$appoggio = floor ($SESSION["max_file_size_images"] / 1024);
$no_product_image_chosen = "Non &egrave; stata scelta una nuova immagine per rappresentare il prodotto, oppure l'immagine scelta &egrave; troppo grande: " . $appoggio . " bytes max";
$image_upload_failed = "Upload dell'immagine fallito";
$unsupported_image_type = "Tipo di immagine non supportato";

////////////////////////////////////////////////////////////
// advanced search
// prefix table: L = left	R = right
//		M = male	F = female
//		S = singular	P = plural
////////////////////////////////////////////////////////////

$there_are_errors = "Ci sono errori nei parametri sottomessi";

$AdvancedSearch = "Ricerca Avanzata";

//$Less_or_Equal = "&le";
$min = "min &nbsp;";
$max = "&nbsp; max";
//$Subset_or_Equal = "&sube";
$Subset_or_Equal = "";

//////////////////////////////////////////////////
// Math symbols (only for Browser with full Html
// entities support (like Mozilla Mxx))
// or, maybe, it's only a matter of font ?
// $LMS_Less_or_Equal = "&le;";
// $LMP_Less_or_Equal = "&le;";
// $LFS_Less_or_Equal = "&le;";
// $LFP_Less_or_Equal = "&le;";
// $RMS_Less_or_Equal = "&le;";
// $RMP_Less_or_Equal = "&le;";
// $RFS_Less_or_Equal = "&le;";
// $RFP_Less_or_Equal = "&le;";
// $M_Subset_or_Equal = "&sube;";
// $F_Subset_or_Equal = "&sube;";
//////////////////////////////////////////////////
$LMS_Less_or_Equal = "";
$LMP_Less_or_Equal = "";
$LFS_Less_or_Equal = "";
$LFP_Less_or_Equal = "";
$RMS_Less_or_Equal = "compreso tra";
$RMP_Less_or_Equal = "compresi tra";
$RFS_Less_or_Equal = "compresa tra";
$RFP_Less_or_Equal = "comprese tra";
$M_Subset_or_Equal = "contenuto nel";
$F_Subset_or_Equal = "contenuto nella";

////////////////////////////////////////////////////////////

$connection_error = "Errore di connessione alla base di dati";

$submission_to_banca_sella = "Pagamento con Carta di Credito";
$no_more_passwordric = "Sono temporaneamente finite le password necessarie per l'interfacciamento con E-Commerce Online, impossibile effettuare il pagamento con Carta di Credito";

?>
